@@ -2,11 +2,17 @@ from .src.search_range import search_range
 from .src.status_bar import status_bar
 from .src.logger import Logger, DummyLog
 from .src.misc import (
+    clump,
     split_iterable,
     byte_xor,
     intToBytes,
     bytesToInt,
     hashfile,
-    byteSize
+    byteSize,
+    first,
+    splice,
+    context_lock,
+    LockTimeoutExceeded,
 )
 from .src.shell import cmd, StdOutAdapter, ShellReturnObject
+from .src.active_timeout import ActiveTimeout, TimeoutExceeded
